[chronojump] 'Inclinated' -> 'inclined'



commit 46dc2a6490067c7f0c52fe6ca14117e2b98d9ae7
Author: Xavier de Blas <xaviblas gmail com>
Date:   Mon Nov 2 11:50:43 2015 +0100

    'Inclinated' -> 'inclined'

 encoder/util.R        |    2 +-
 src/encoder.cs        |   12 ++++++------
 src/sqlite/encoder.cs |    8 ++++----
 src/sqlite/main.cs    |   19 +++++++++++++++----
 4 files changed, 26 insertions(+), 15 deletions(-)
---
diff --git a/encoder/util.R b/encoder/util.R
index b010b0e..c7260ce 100644
--- a/encoder/util.R
+++ b/encoder/util.R
@@ -772,7 +772,7 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
     angleSpeed = speed * 4 / diameter.m
     angleAccel = accel * 4 / diameter.m
     anglePush = 90 #TODO: send from C#
-    #The configuration covers horizontal, vertical and inclinated movements
+    #The configuration covers horizontal, vertical and inclined movements
     #If the movement is vertical g*sin(alpha) = g
     #If the movement is horizontal g*sin(alpha) = 0
 
diff --git a/src/encoder.cs b/src/encoder.cs
index b5b114d..959a504 100644
--- a/src/encoder.cs
+++ b/src/encoder.cs
@@ -772,8 +772,8 @@ public class EncoderExercise
                                name == "Squat" ||
                                name == "Free" ||
                                name == "Jump" ||
-                               name == "Inclinated plane" ||
-                               name == "Inclinated plane BW" )
+                               name == "Inclined plane" ||
+                               name == "Inclined plane BW" )
                        return true;
                else 
                        return false;
@@ -1047,8 +1047,8 @@ public class EncoderConfiguration {
                        type = Constants.EncoderType.LINEAR;
                        position = 7;
                        image = Constants.FileNameEncoderLinearOnPlane;
-                       code = "Linear - inclinated plane";
-                       text = Catalog.GetString("Linear encoder on a inclinated plane.") + "\n" + 
+                       code = "Linear - inclined plane";
+                       text = Catalog.GetString("Linear encoder on a inclined plane.") + "\n" + 
                                Catalog.GetString("Suitable also for horizontal movement. Just set a 0 push 
angle.");
                        
                        has_angle_push = true;
@@ -1058,8 +1058,8 @@ public class EncoderConfiguration {
                        type = Constants.EncoderType.LINEAR;
                        position = 8;
                        image = Constants.FileNameEncoderLinearOnPlaneWeightDiffAngle;
-                       code = "Linear - inclinated plane different angle";
-                       text = Catalog.GetString("Linear encoder on a inclinated plane moving a weight in 
different angle.") + "\n" +
+                       code = "Linear - inclined plane different angle";
+                       text = Catalog.GetString("Linear encoder on a inclined plane moving a weight in 
different angle.") + "\n" +
                                Catalog.GetString("Suitable also for horizontal movement. Just set a 0 push 
angle.");
                        
                        has_angle_push = true;
diff --git a/src/sqlite/encoder.cs b/src/sqlite/encoder.cs
index ad40601..04e1fc4 100644
--- a/src/sqlite/encoder.cs
+++ b/src/sqlite/encoder.cs
@@ -561,7 +561,7 @@ class SqliteEncoder : Sqlite
 
                addEncoderFreeExercise();
                addEncoderJumpExercise();
-               addEncoderInclinatedExercises();
+               addEncoderInclinedExercises();
        }
 
        //written just to have the names translated
@@ -580,12 +580,12 @@ class SqliteEncoder : Sqlite
                if(! exists)
                        InsertExercise(true, "Jump", 100, "", "", "");
        }
-       protected internal static void addEncoderInclinatedExercises()
+       protected internal static void addEncoderInclinedExercises()
        {
                string [] iniEncoderExercises = {
                        //name:percentBodyWeight:ressistance:description:speed1RM:bodyAngle:weightAngle
-                       "Inclinated plane:0:machine::::",
-                       "Inclinated plane BW:100:machine::::",
+                       "Inclined plane:0:machine::::",
+                       "Inclined plane BW:100:machine::::",
                };
                
                foreach(string line in iniEncoderExercises) {
diff --git a/src/sqlite/main.cs b/src/sqlite/main.cs
index 68e0533..6e09e55 100644
--- a/src/sqlite/main.cs
+++ b/src/sqlite/main.cs
@@ -77,7 +77,7 @@ class Sqlite
        /*
         * Important, change this if there's any update to database
         */
-       static string lastChronojumpDatabaseVersion = "1.25";
+       static string lastChronojumpDatabaseVersion = "1.26";
 
        public Sqlite() {
        }
@@ -1419,9 +1419,9 @@ class Sqlite
 
                                SqliteEncoder.putEncoderExerciseAnglesAt90();
                                SqliteEncoder.addEncoderJumpExercise();
-                               SqliteEncoder.addEncoderInclinatedExercises();
+                               SqliteEncoder.addEncoderInclinedExercises();
 
-                               LogB.SQL("Added Free and inclinatedExercises");
+                               LogB.SQL("Added Free and inclinedExercises");
                                SqlitePreferences.Update ("databaseVersion", "1.00", true); 
                                Sqlite.Close();
 
@@ -1845,6 +1845,16 @@ class Sqlite
                                SqlitePreferences.Update ("databaseVersion", newVersion, true); 
                                currentVersion = newVersion;
                        }
+                       if(currentVersion == "1.25") {
+                               LogB.SQL("Changed Inclinated to Inclined");
+                               Update(true, Constants.EncoderExerciseTable, "name", "Inclinated plane", 
"Inclined plane", "", "");
+                               Update(true, Constants.EncoderExerciseTable, "name", "Inclinated plane BW", 
"Inclined plane BW", "", "");
+                               
+                               newVersion = "1.26";
+                               SqlitePreferences.Update ("databaseVersion", newVersion, true); 
+                               currentVersion = newVersion;
+                       }
+
 
                        // --- add more updates here
                
@@ -1999,6 +2009,7 @@ class Sqlite
                SqliteExecuteAuto.addChronojumpProfileAndBilateral();
                
                //changes [from - to - desc]
+               //1.25 - 1.26 Converted DB to 1.26 Changed Inclinated to Inclined
                //1.24 - 1.25 Converted DB to 1.25 Language defaults to (empty string), means detected
                //1.23 - 1.24 Converted DB to 1.24 Delete runISpeedStartArrival and add 4 double contacts 
configs
                //1.22 - 1.23 Converted DB to 1.23 Added encoder configuration
@@ -2024,7 +2035,7 @@ class Sqlite
                //1.02 - 1.03 Converted DB to 1.03 Updated encoder exercise, angle is now on encoder 
configuration
                //1.01 - 1.02 Converted DB to 1.02 Added Agility Tests: Agility-T-Test, Agility-3L3R
                //1.00 - 1.01 Converted DB to 1.01 Added export to CSV configuration on preferences
                //0.99 - 1.00 Converted DB to 1.00 Encoder added Free and Inclinated Exercises
                //0.98 - 0.99 Converted DB to 0.99 Encoder table improved 
                //0.97 - 0.98 Converted DB to 0.98 Fixed encoder laterality
                //0.96 - 0.97 Converted DB to 0.97 Added inertialmomentum in preferences
@@ -2024,7 +2035,7 @@ class Sqlite
                //1.01 - 1.02 Converted DB to 1.02 Added Agility Tests: Agility-T-Test, Agility-3L3R
                //1.00 - 1.01 Converted DB to 1.01 Added export to CSV configuration on preferences
-               //0.99 - 1.00 Converted DB to 1.00 Encoder added Free and Inclinated Exercises
+               //0.99 - 1.00 Converted DB to 1.00 Encoder added Free and Inclined Exercises
                //0.98 - 0.99 Converted DB to 0.99 Encoder table improved 
                //0.97 - 0.98 Converted DB to 0.98 Fixed encoder laterality


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]